@@ -97,8 +97,17 @@ class Avto(models.Model):
     STATUS = (("AVAILABLE", "Available"), ("BOOKED", "Booked"), ("SOLD", "Sold"))
     status = models.CharField(max_length=16, blank=True, verbose_name='Status of ad', choices=STATUS, default='available')
 
+    CONDITIONS = (
+        ('new', 'new'),
+        ('used', 'used'),
+        ('refurbished', 'refurbished'),
+        ('repaired', 'repaired'),
+        ('as_is', 'as is'),
+        ('other', 'other')
+    )
+
     odometer_desc = models.CharField(max_length=255, blank=True, verbose_name='Odometer description', default='')
-    condition = models.CharField(max_length=255, blank=True, verbose_name='Condition', default='')
+    condition = models.CharField(max_length=255, blank=True, verbose_name='Condition', default='', choices=CONDITIONS)
 
     def get_fields(self):
         return [(field.verbose_name, field.value_from_object(self)) for field in self.__class__._meta.fields]
